@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2016-10-07'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use strict;
@@ -517,7 +517,7 @@ $SPEC{gen_getopt_long_spec_from_meta} = {
     summary     => 'Generate Getopt::Long spec from Rinci function metadata',
     description => <<'_',
 
-This routine will produce a `Getopt::Long` specification from Rinci function
+This routine will produce a <pm:Getopt::Long> specification from Rinci function
 metadata, as well as some more data structure in the result metadata to help
 producing a command-line help/usage message.
 
@@ -734,7 +734,7 @@ $SPEC{get_args_from_argv} = {
 Using information in Rinci function metadata's `args` property, parse command
 line arguments `@argv` into hash `%args`, suitable for passing into subroutines.
 
-Currently uses Getopt::Long's GetOptions to do the parsing.
+Currently uses <pm:Getopt::Long>'s `GetOptions` to do the parsing.
 
 As with GetOptions, this function modifies its `argv` argument, so you might
 want to copy the original `argv` first (or pass a copy instead) if you want to
@@ -1100,7 +1100,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-08-24.
+This document describes version 0.74 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2016-10-07.
 
 =head1 SYNOPSIS
 
@@ -1122,7 +1122,7 @@ processed, see Perinci::CmdLine's documentation.
 
 Generate Getopt::Long spec from Rinci function metadata.
 
-This routine will produce a C<Getopt::Long> specification from Rinci function
+This routine will produce a L<Getopt::Long> specification from Rinci function
 metadata, as well as some more data structure in the result metadata to help
 producing a command-line help/usage message.
 
@@ -1250,7 +1250,7 @@ Get subroutine arguments (%args) from command-line arguments (@ARGV).
 Using information in Rinci function metadata's C<args> property, parse command
 line arguments C<@argv> into hash C<%args>, suitable for passing into subroutines.
 
-Currently uses Getopt::Long's GetOptions to do the parsing.
+Currently uses L<Getopt::Long>'s C<GetOptions> to do the parsing.
 
 As with GetOptions, this function modifies its C<argv> argument, so you might
 want to copy the original C<argv> first (or pass a copy instead) if you want to
@@ -1408,7 +1408,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-GetArgs-Argv>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-GetArgs-Argv>.
 
 =head1 BUGS
 
